
#include "xpex.h"
#include "defs.h"
#include <stdio.h>

extern int cur_light;
extern int cur_shading;
extern int cur_refl;
extern int cur_hlhsr_mode;
extern int num_on, num_off;
extern PEXTableIndex light_on[4];
extern PEXTableIndex light_off[4];
extern PEXLightEntry lights[4];

/*
 * if you change any of the %.3f you would also need to change
 * viewobject/callbacks.c:set_light
 */

void printColor( colorSpec )
PEXColorSpecifier colorSpec;
{
    switch( colorSpec.type ) {
        case PEXColorTypeRGB :
            fprintf( stdout, "RGB %.3f %.3f %.3f\n",
                    colorSpec.value.rgb.red,
                    colorSpec.value.rgb.green,
                    colorSpec.value.rgb.blue );
            break;
        case PEXColorTypeHSV :
            fprintf( stdout, "HSV %.3f %.3f %.3f\n",
                    colorSpec.value.hsv.hue,
                    colorSpec.value.hsv.saturation,
                    colorSpec.value.hsv.value );
            break;
        case PEXColorTypeHLS :
            fprintf( stdout, "HLS %.3f %.3f %.3f\n",
                    colorSpec.value.hls.hue,
                    colorSpec.value.hls.lightness,
                    colorSpec.value.hls.saturation );
            break;
        case PEXColorTypeCIE :
            fprintf( stdout, "CIE %.3f %.3f %.3f\n",
                    colorSpec.value.cie.x,
                    colorSpec.value.cie.y,
                    colorSpec.value.cie.z );
            break;
        default :
            break;
    }
}


void printLight()
{
    int i;

    fprintf( stdout, "Lgts ON %d\n", num_on );
    for( i=0; i<num_on; i++ ) {
        switch( light_on[i]-1 ) {
            case AMBIENT:
                fprintf( stdout, "Amb " );
                printColor( lights[AMBIENT].color );
                break;
            case DIRECTIONAL:
                fprintf( stdout, "Dir " );
                fprintf( stdout, "%.3f %.3f %.3f ",
                    lights[DIRECTIONAL].direction.x,
                    lights[DIRECTIONAL].direction.y,
                    lights[DIRECTIONAL].direction.z );
                printColor( lights[DIRECTIONAL].color );
                break;
            case POSITIONAL:
                fprintf( stdout, "Pos " );
                fprintf( stdout, "%.3f %.3f %.3f ",
                    lights[POSITIONAL].point.x,
                    lights[POSITIONAL].point.y,
                    lights[POSITIONAL].point.z );
                fprintf( stdout, "%.3f %.3f ",
                    lights[POSITIONAL].attenuation1,
                    lights[POSITIONAL].attenuation2 );
                printColor( lights[POSITIONAL].color );
                break;
            case SPOT:
                fprintf( stdout, "Spt " );
                fprintf( stdout, "%.3f %.3f %.3f ",
                    lights[SPOT].point.x,
                    lights[SPOT].point.y,
                    lights[SPOT].point.z );
                fprintf( stdout, "%.3f %.3f %.3f ",
                    lights[SPOT].direction.x,
                    lights[SPOT].direction.y,
                    lights[SPOT].direction.z );
                fprintf( stdout, "%.3f %.3f ",
                    lights[SPOT].attenuation1,
                    lights[SPOT].attenuation2 );
                fprintf( stdout, "%.3f %.3f ",
                    lights[SPOT].concentration,
                    lights[SPOT].spread_angle );
                printColor( lights[SPOT].color );
                break;
        }
    }

    fprintf( stdout, "Lgts OF %d\n", num_off );
    for( i=0; i<num_off; i++ ) {
        switch( light_off[i]-1 ) {
            case AMBIENT:
                fprintf( stdout, "Amb " );
                printColor( lights[AMBIENT].color );
                break;
            case DIRECTIONAL:
                fprintf( stdout, "Dir " );
                fprintf( stdout, "%.3f %.3f %.3f ",
                    lights[DIRECTIONAL].direction.x,
                    lights[DIRECTIONAL].direction.y,
                    lights[DIRECTIONAL].direction.z );
                printColor( lights[DIRECTIONAL].color );
                break;
            case POSITIONAL:
                fprintf( stdout, "Pos " );
                fprintf( stdout, "%.3f %.3f %.3f ",
                    lights[POSITIONAL].point.x,
                    lights[POSITIONAL].point.y,
                    lights[POSITIONAL].point.z );
                fprintf( stdout, "%.3f %.3f ",
                    lights[POSITIONAL].attenuation1,
                    lights[POSITIONAL].attenuation2 );
                printColor( lights[POSITIONAL].color );
                break;
            case SPOT:
                fprintf( stdout, "Spt " );
                fprintf( stdout, "%.3f %.3f %.3f ",
                    lights[SPOT].point.x,
                    lights[SPOT].point.y,
                    lights[SPOT].point.z );
                fprintf( stdout, "%.3f %.3f %.3f ",
                    lights[SPOT].direction.x,
                    lights[SPOT].direction.y,
                    lights[SPOT].direction.z );
                fprintf( stdout, "%.3f %.3f ",
                    lights[SPOT].attenuation1,
                    lights[SPOT].attenuation2 );
                fprintf( stdout, "%.3f %.3f ",
                    lights[SPOT].concentration,
                    lights[SPOT].spread_angle );
                printColor( lights[SPOT].color );
                break;
        }
    }

    switch( cur_shading ) {
        case PEXSurfaceInterpNone:
            fprintf( stdout, "Shad Non\n" );
            break;
        case PEXSurfaceInterpColor:
            fprintf( stdout, "Shad Clr\n" );
            break;
        case PEXSurfaceInterpDotProduct:
            fprintf( stdout, "Shad Dot\n" );
            break;
        case PEXSurfaceInterpNormal:
            fprintf( stdout, "Shad Nor\n" );
            break;
    }
    switch( cur_refl ) {
        case PEXReflectionNone:
            fprintf( stdout, "Refl Non\n" );
            break;
        case PEXReflectionAmbient:
            fprintf( stdout, "Refl Amb\n" );
            break;
        case PEXReflectionDiffuse:
            fprintf( stdout, "Refl Dif\n" );
            break;
        case PEXReflectionSpecular:
            fprintf( stdout, "Refl Spc\n" );
            break;
    }
}
